@@ -2,7 +2,7 @@
 
 # Entry point script for netatalk docker container.
 # Copyright (C) 2023  Eric Harmon
-# Copyright (C) 2024-2025  Daniel Markstedt
+# Copyright (C) 2024-2025  Daniel Markstedt <daniel@mindani.net>
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -203,10 +203,10 @@ fi
 
 # Configuring AppleTalk if enabled
 if [ -n "$ATALKD_INTERFACE" ]; then
-    echo "*** Configuring DDP"
+    echo "*** Configuring DDP services"
     echo "$ATALKD_INTERFACE $ATALKD_OPTIONS" > /usr/local/etc/atalkd.conf
     echo "cupsautoadd:op=root:" > /usr/local/etc/papd.conf
-    echo "*** Starting DDP services"
+    echo "*** Starting DDP services (this will take a minute)"
     cupsd
     atalkd
     papd
