@@ -4,7 +4,7 @@
  */
 
 #ifdef HAVE_CONFIG_H
-#include <config.h>
+#include "config.h"
 #endif /* HAVE_CONFIG_H */
 
 #include <string.h>
@@ -18,9 +18,7 @@
 
 /* POSIX.1 sys/wait.h check */
 #include <sys/types.h>
-#ifdef HAVE_SYS_WAIT_H
 #include <sys/wait.h>
-#endif /* HAVE_SYS_WAIT_H */
 #ifndef WEXITSTATUS
 #define WEXITSTATUS(stat_val) ((unsigned)(stat_val) >> 8)
 #endif /* ! WEXITSTATUS */
@@ -43,7 +41,6 @@
 #include <atalk/compat.h>
 #include <atalk/atp.h>
 #include <atalk/pap.h>
-#include <atalk/paths.h>
 #include <atalk/util.h>
 #include <atalk/nbp.h>
 #include <atalk/unicode.h>
@@ -54,13 +51,14 @@
 #include "uam_auth.h"
 #include "print_cups.h"
 
+#define MACCHARSET "MAC_ROMAN"
 
 /* This maps to TReq and TResp, per "Inside AppleTalk" 10-13 */
 
 typedef struct __attribute__((__packed__)) {
-	u_int8_t user_bytes[4];
-	u_int8_t data_bytes[4];
-	u_int8_t buf_len;
+	uint8_t user_bytes[4];
+	uint8_t data_bytes[4];
+	uint8_t buf_len;
 	char buf[255];
 } rbuf_t;
 
@@ -76,7 +74,7 @@ unsigned char	connid, quantum, sock, oquantum = PAP_MAXQUANTUM;
 char		*cannedstatus = "status: print spooler processing job";
 struct printer	*printer = NULL;
 char		*version = VERSION;
-static char	*pidfile = _PATH_PAPDLOCK;
+static char	*pidfile = PATH_PAPD_LOCK;
 
 char		*uamlist;
 char		*uampath = _PATH_PAPDUAMPATH;
@@ -165,6 +163,11 @@ int main(int ac, char **av)
     char		cbuf[ 8 ];
     int			c;
     char 		*atname;
+    char* string, * macName = MACCHARSET;
+
+    /* Set codepages here since it is no longer auto-initialzed anymore*/
+    set_charset_name(CH_UNIX, "UTF8");
+    set_charset_name(CH_MAC, MACCHARSET);
 
     if ( gethostname( hostname, sizeof( hostname )) < 0 ) {
 	perror( "gethostname" );
@@ -199,7 +202,7 @@ int main(int ac, char **av)
     defprinter.p_pagecost_msg = NULL;
     defprinter.p_lock = "lock";
 
-    while (( c = getopt( ac, av, "adf:p:P:v" )) != EOF ) {
+    while (( c = getopt( ac, av, "adVvf:p:P:" )) != EOF ) {
 	switch ( c ) {
 	case 'a' :		/* for compatibility with old papd */
 	    break;
@@ -220,8 +223,9 @@ int main(int ac, char **av)
 	    pidfile = optarg;
 	    break;
 
+	case 'V' :
 	case 'v' :		/* version */
-	    printf( "papd (version %s)\n", VERSION );
+	    printf( "papd %s - Printer Access Protocol Daemon\n", version );
 	    exit ( 1 );
 	    break;
 
@@ -245,9 +249,9 @@ int main(int ac, char **av)
       exit(1);
     default:
       exit(0);
-    }      
+    }
 
-    if ( debug ) 
+    if ( debug )
 	fault_setup(NULL);
 
     /*
@@ -280,7 +284,7 @@ int main(int ac, char **av)
 			pr->p_name = atname;
 		}
 	}
-			
+
 	if (( pr->p_atp = atp_open( ATADDR_ANYPORT, &pr->p_addr )) == NULL ) {
 	    LOG(log_error, logtype_papd, "atp_open: %s", strerror(errno) );
 	    papd_exit( 1 );
@@ -406,7 +410,7 @@ int main(int ac, char **av)
 		     * just die(), let's try to continue. Maybe some sockets
 		     * will close, and we can continue;
 		     */
-		    if (( atp = atp_open( ATADDR_ANYPORT, 
+		    if (( atp = atp_open( ATADDR_ANYPORT,
 					  &pr->p_addr)) == NULL ) {
 			LOG(log_error, logtype_papd, "atp_open: %s", strerror(errno) );
 			r_buf.user_bytes[2] = 0xff;
@@ -472,7 +476,7 @@ int main(int ac, char **av)
 			    LOG(log_error, logtype_papd, "sigaction: %s", strerror(errno) );
 			    exit( 1 );
 			}
-			
+
 			if ( sigaction( SIGCHLD, &sv, NULL ) < 0 ) {
 			    LOG(log_error, logtype_papd, "sigaction: %s", strerror(errno) );
 			    exit( 1 );
@@ -558,13 +562,13 @@ int getstatus(struct printer *pr, rbuf_t *buf)
 #ifdef HAVE_CUPS
     if ( pr->p_flags & P_PIPED ) {
 	buf->buf_len = strlen(cannedstatus);
-	snprintf(buf->buf, 254, "%s", cannedstatus);
-	return (buf->buf_len + 1);
+	snprintf(buf->buf, 255, "%s", cannedstatus);
+	return buf->buf_len + 1;
     } else {
 	cups_get_printer_status( pr );
 	buf->buf_len = strlen(pr->p_status);
-	snprintf(buf->buf, 254, "%s", pr->p_status);
-	return (buf->buf_len + 1);
+	snprintf(buf->buf, 255, "%s", pr->p_status);
+	return buf->buf_len + 1;
     }
 #else
     char path[MAXPATHLEN];
@@ -580,8 +584,8 @@ int getstatus(struct printer *pr, rbuf_t *buf)
 
     if ((pr->p_flags & P_PIPED) || (fd == NULL)) {
 	buf->buf_len = strlen(cannedstatus);
-	snprintf(buf->buf, 254, "%s", cannedstatus);
-	return (buf->buf_len + 1);
+	snprintf(buf->buf, 255, "%s", cannedstatus);
+	return buf->buf_len + 1;
     } else {
 	rc = fread(getstatus_buffer, 255, sizeof(unsigned char), fd);
 	fclose(fd);
@@ -589,15 +593,15 @@ int getstatus(struct printer *pr, rbuf_t *buf)
 	if (rc > 0) {
 		if (temp != NULL) {
 			temp[strcspn(temp, "\n")] = '\0';
-			snprintf(buf->buf, 254, "%s", temp);
+			snprintf(buf->buf, 255, "%s", temp);
 			buf->buf_len = strlen(buf->buf);
 		}
 	} else {
-		snprintf(buf->buf, 254, "%s", "thisisanemptystring");
+		snprintf(buf->buf, 255, "%s", "thisisanemptystring");
 		buf->buf_len = 0;
 	}
 
-	return (buf->buf_len + 1);
+	return buf->buf_len + 1;
     }
 #endif /* HAVE_CUPS */
 }
@@ -744,9 +748,9 @@ static void getprinters( char *cf)
 	}
 
 	/* get printer's appletalk address. */
-	if (( p = pgetstr( "pa", &a )) == NULL ) 
+	if (( p = pgetstr( "pa", &a )) == NULL )
 	    memcpy(&pr->p_addr, &defprinter.p_addr, sizeof(pr->p_addr));
-	else 
+	else
 	    atalk_aton(p, &pr->p_addr);
 
 #ifdef HAVE_CUPS
@@ -803,7 +807,7 @@ int rprintcap( struct printer *pr)
     if ( pr->p_flags & P_SPOOLED && !(pr->p_flags & P_CUPS_AUTOADDED) ) { /* Skip check if autoadded */
 	if ( cups_printername_ok ( pr->p_printer ) != 1) {
 	    LOG(log_error, logtype_papd, "No such CUPS printer: '%s'", pr->p_printer );
-	    return( -1 );
+	    return -1;
 	}
     }
 
@@ -835,7 +839,7 @@ int rprintcap( struct printer *pr)
     if ( pr->p_flags & P_SPOOLED ) {
 	if ( pgetent( printcap, buf, pr->p_printer ) != 1 ) {
 	    LOG(log_error, logtype_papd, "No such printer: %s", pr->p_printer );
-	    return( -1 );
+	    return -1;
 	}
 
 	/*
@@ -934,5 +938,5 @@ int rprintcap( struct printer *pr)
     }
 #endif /* HAVE_CUPS */
 
-    return( 0 );
+    return 0;
 }
