@@ -1,22 +1,26 @@
 /*
  * Copyright (C) Ralph Boehme 2013
  * All Rights Reserved.  See COPYING.
+ * 
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
  */
 
+#ifdef _FORTIFY_SOURCE
+#undef _FORTIFY_SOURCE
+#endif
+
 #ifdef HAVE_CONFIG_H
 #include "config.h"
 #endif /* HAVE_CONFIG_H */
 
-#undef _FORTIFY_SOURCE
-
 #include <arpa/inet.h>
-#include <arpa/inet.h>
-#include <errno.h>
 #include <errno.h>
 #include <net/if.h>
 #include <netdb.h>
 #include <netinet/in.h>
-#include <netinet/in.h>
 #include <netinet/tcp.h>
 #include <stdlib.h>
 #include <sys/param.h>
@@ -299,7 +303,7 @@ int cnid_mysql_update(struct _cnid_db *cdb,
 {
     EC_INIT;
     CNID_mysql_private *db;
-    cnid_t update_id;
+    cnid_t update_id = 0;
 
     if (!cdb || !(db = cdb->cnid_db_private) || !id || !st || !name) {
         LOG(log_error, logtype_cnid, "cnid_update: Parameter error");
@@ -741,15 +745,15 @@ EC_CLEANUP:
 }
 
 
-int cnid_mysql_find(struct _cnid_db *cdb, const char *name, size_t namelen, void *buffer, size_t buflen)
+int cnid_mysql_find(struct _cnid_db *cdb _U_, const char *name, size_t namelen _U_, void *buffer _U_, size_t buflen _U_)
 {
     LOG(log_error, logtype_cnid,
         "cnid_mysql_find(\"%s\"): not supported with MySQL CNID backend", name);
     return -1;
 }
 
-cnid_t cnid_mysql_rebuild_add(struct _cnid_db *cdb, const struct stat *st,
-                              cnid_t did, const char *name, size_t len, cnid_t hint)
+cnid_t cnid_mysql_rebuild_add(struct _cnid_db *cdb _U_, const struct stat *st _U_,
+                              cnid_t did _U_, const char *name, size_t len _U_, cnid_t hint _U_)
 {
     LOG(log_error, logtype_cnid,
         "cnid_mysql_rebuild_add(\"%s\"): not supported with MySQL CNID backend", name);
